@@ -340,11 +340,12 @@ async fn install(
     builder = builder.forge(forge.clone());
     builder = set_token(builder, &forge);
 
-    if let Some(api_url) = opts.get("api_url") {
-        if !api_url.contains("github.com") && !api_url.contains("gitlab.com") {
-            builder = builder.api_base_url(api_url.strip_suffix("/").unwrap_or(api_url));
-            builder = set_enterprise_token(builder, &forge);
-        }
+    if let Some(api_url) = opts.get("api_url")
+        && !api_url.contains("github.com")
+        && !api_url.contains("gitlab.com")
+    {
+        builder = builder.api_base_url(api_url.strip_suffix("/").unwrap_or(api_url));
+        builder = set_enterprise_token(builder, &forge);
     }
 
     let mut ubi = builder.build().map_err(|e| eyre::eyre!(e))?;
