@@ -159,10 +159,10 @@ impl ToolStub {
             .unwrap_or("");
 
         // Update bin if provided and different from stub filename
-        if let Some(bin) = &self.bin {
-            if bin != stub_filename {
-                doc["bin"] = toml_edit::value(bin);
-            }
+        if let Some(bin) = &self.bin
+            && bin != stub_filename
+        {
+            doc["bin"] = toml_edit::value(bin);
         }
 
         // We use toml_edit directly to preserve existing content
@@ -185,12 +185,12 @@ impl ToolStub {
                 }
                 doc["size"] = size_item;
 
-                if self.bin.is_none() {
-                    if let Some(detected_bin) = bin_path.as_ref() {
-                        // Only set bin if it's different from the stub filename
-                        if detected_bin != stub_filename {
-                            doc["bin"] = toml_edit::value(detected_bin);
-                        }
+                if self.bin.is_none()
+                    && let Some(detected_bin) = bin_path.as_ref()
+                {
+                    // Only set bin if it's different from the stub filename
+                    if detected_bin != stub_filename {
+                        doc["bin"] = toml_edit::value(detected_bin);
                     }
                 }
             }
@@ -230,10 +230,10 @@ impl ToolStub {
                 platform_table["url"] = toml_edit::value(&url);
 
                 // Set platform-specific bin path if explicitly provided and different from stub filename
-                if let Some(explicit_bin) = explicit_platform_bins.get(&platform) {
-                    if explicit_bin != stub_filename {
-                        platform_table["bin"] = toml_edit::value(explicit_bin);
-                    }
+                if let Some(explicit_bin) = explicit_platform_bins.get(&platform)
+                    && explicit_bin != stub_filename
+                {
+                    platform_table["bin"] = toml_edit::value(explicit_bin);
                 }
 
                 // Auto-detect checksum, size, and bin path if not skipped
@@ -255,12 +255,12 @@ impl ToolStub {
                     }
 
                     // Set bin path if not explicitly provided and we detected one different from stub filename
-                    if !explicit_platform_bins.contains_key(&platform) && self.bin.is_none() {
-                        if let Some(detected_bin) = bin_path.as_ref() {
-                            if detected_bin != stub_filename {
-                                platform_table["bin"] = toml_edit::value(detected_bin);
-                            }
-                        }
+                    if !explicit_platform_bins.contains_key(&platform)
+                        && self.bin.is_none()
+                        && let Some(detected_bin) = bin_path.as_ref()
+                        && detected_bin != stub_filename
+                    {
+                        platform_table["bin"] = toml_edit::value(detected_bin);
                     }
                 }
             }
@@ -278,12 +278,11 @@ impl ToolStub {
                 // Remove platform-specific bin entries since we'll have a global one
                 for platform_spec in &self.platform_url {
                     let (platform, _) = self.parse_platform_spec(platform_spec)?;
-                    if let Some(platform_table) = platforms.get_mut(&platform) {
-                        if let Some(table) = platform_table.as_table_mut() {
-                            if !explicit_platform_bins.contains_key(&platform) {
-                                table.remove("bin");
-                            }
-                        }
+                    if let Some(platform_table) = platforms.get_mut(&platform)
+                        && let Some(table) = platform_table.as_table_mut()
+                        && !explicit_platform_bins.contains_key(&platform)
+                    {
+                        table.remove("bin");
                     }
                 }
                 // Now set the global bin if different from stub filename
@@ -475,10 +474,10 @@ impl ToolStub {
             let entry = entry?;
             if entry.file_type().is_file() {
                 let path = entry.path();
-                if file::is_executable(path) {
-                    if let Ok(relative_path) = path.strip_prefix(dir) {
-                        executables.push(relative_path.to_string_lossy().to_string());
-                    }
+                if file::is_executable(path)
+                    && let Ok(relative_path) = path.strip_prefix(dir)
+                {
+                    executables.push(relative_path.to_string_lossy().to_string());
                 }
             }
         }
@@ -500,10 +499,10 @@ impl ToolStub {
                     return Ok(exe.clone());
                 }
                 // Check filename without extension
-                if let Some(stem) = path.file_stem().and_then(|f| f.to_str()) {
-                    if stem == tool_name {
-                        return Ok(exe.clone());
-                    }
+                if let Some(stem) = path.file_stem().and_then(|f| f.to_str())
+                    && stem == tool_name
+                {
+                    return Ok(exe.clone());
                 }
             }
         }
@@ -606,28 +605,28 @@ impl ToolStub {
         // Process platform-specific URLs
         if let Some(platforms) = doc.get_mut("platforms").and_then(|p| p.as_table_mut()) {
             for (platform_name, platform_value) in platforms.iter_mut() {
-                if let Some(platform_table) = platform_value.as_table_mut() {
-                    if let Some(url) = platform_table.get("url").and_then(|v| v.as_str()) {
-                        // Only fetch if checksum is missing for this platform
-                        if platform_table.get("checksum").is_none() {
-                            match self.analyze_url(url, &mpr).await {
-                                Ok((checksum, size, _)) => {
-                                    platform_table["checksum"] = toml_edit::value(&checksum);
+                if let Some(platform_table) = platform_value.as_table_mut()
+                    && let Some(url) = platform_table.get("url").and_then(|v| v.as_str())
+                {
+                    // Only fetch if checksum is missing for this platform
+                    if platform_table.get("checksum").is_none() {
+                        match self.analyze_url(url, &mpr).await {
+                            Ok((checksum, size, _)) => {
+                                platform_table["checksum"] = toml_edit::value(&checksum);
 
-                                    // Create size entry with human-readable comment
-                                    let mut size_item = toml_edit::value(size as i64);
-                                    if let Some(value) = size_item.as_value_mut() {
-                                        let formatted_comment = format_size_comment(size);
-                                        value.decor_mut().set_suffix(formatted_comment);
-                                    }
-                                    platform_table["size"] = size_item;
-                                }
-                                Err(e) => {
-                                    // Log error but continue with other platforms
-                                    eprintln!(
-                                        "Warning: Failed to fetch checksum for platform '{platform_name}': {e}"
-                                    );
+                                // Create size entry with human-readable comment
+                                let mut size_item = toml_edit::value(size as i64);
+                                if let Some(value) = size_item.as_value_mut() {
+                                    let formatted_comment = format_size_comment(size);
+                                    value.decor_mut().set_suffix(formatted_comment);
                                 }
+                                platform_table["size"] = size_item;
+                            }
+                            Err(e) => {
+                                // Log error but continue with other platforms
+                                eprintln!(
+                                    "Warning: Failed to fetch checksum for platform '{platform_name}': {e}"
+                                );
                             }
                         }
                     }
