@@ -769,10 +769,11 @@ impl Run {
             }
             return Ok(());
         }
-        if let Some(message) = &task.confirm {
-            if !Settings::get().yes && !ui::confirm(message).unwrap_or(false) {
-                return Err(eyre!("aborted by user"));
-            }
+        if let Some(message) = &task.confirm
+            && !Settings::get().yes
+            && !ui::confirm(message).unwrap_or(false)
+        {
+            return Err(eyre!("aborted by user"));
         }
 
         let mut tools = self.tool.clone();
@@ -1132,14 +1133,14 @@ impl Run {
     ) -> bool {
         if let (Some(task_config_root), Some(current_config_root)) =
             (task_cf.project_root(), config.project_root.as_ref())
+            && task_config_root == *current_config_root
+            && config_env_entries.is_empty()
         {
-            if task_config_root == *current_config_root && config_env_entries.is_empty() {
-                trace!(
-                    "task {} config root matches current and no config env, using standard env resolution",
-                    task.name
-                );
-                return true;
-            }
+            trace!(
+                "task {} config root matches current and no config env, using standard env resolution",
+                task.name
+            );
+            return true;
         }
         false
     }
@@ -1707,15 +1708,16 @@ impl Run {
     }
 
     fn validate_task(&self, task: &Task) -> Result<()> {
-        if let Some(path) = &task.file {
-            if path.exists() && !file::is_executable(path) {
-                let dp = display_path(path);
-                let msg = format!("Script `{dp}` is not executable. Make it executable?");
-                if ui::confirm(msg)? {
-                    file::make_executable(path)?;
-                } else {
-                    bail!("`{dp}` is not executable")
-                }
+        if let Some(path) = &task.file
+            && path.exists()
+            && !file::is_executable(path)
+        {
+            let dp = display_path(path);
+            let msg = format!("Script `{dp}` is not executable. Make it executable?");
+            if ui::confirm(msg)? {
+                file::make_executable(path)?;
+            } else {
+                bail!("`{dp}` is not executable")
             }
         }
         Ok(())
@@ -2159,20 +2161,19 @@ async fn err_no_task(config: &Config, name: &str) -> Result<()> {
             .iter()
             .map(|d| d.join(name))
             .find(|d| d.is_file() && !file::is_executable(d));
-        if let Some(path) = path {
-            if !cfg!(windows) {
-                warn!(
-                    "no task {} found, but a non-executable file exists at {}",
-                    style::ered(name),
-                    display_path(&path)
-                );
-                let yn = prompt::confirm(
-                    "Mark this file as executable to allow it to be run as a task?",
-                )?;
-                if yn {
-                    file::make_executable(&path)?;
-                    info!("marked as executable, try running this task again");
-                }
+        if let Some(path) = path
+            && !cfg!(windows)
+        {
+            warn!(
+                "no task {} found, but a non-executable file exists at {}",
+                style::ered(name),
+                display_path(&path)
+            );
+            let yn =
+                prompt::confirm("Mark this file as executable to allow it to be run as a task?")?;
+            if yn {
+                file::make_executable(&path)?;
+                info!("marked as executable, try running this task again");
             }
         }
     }
