@@ -120,20 +120,22 @@ impl Set {
             }
         }
 
-        if let Some(env_vars) = &self.env_vars {
-            if env_vars.len() == 1 && env_vars[0].value.is_none() && !self.prompt {
-                let key = &env_vars[0].key;
-                // Use Config's centralized env loading which handles decryption
-                let full_config = Config::get().await?;
-                let env = full_config.env().await?;
-                match env.get(key) {
-                    Some(value) => {
-                        miseprintln!("{value}");
-                    }
-                    None => bail!("Environment variable {key} not found"),
+        if let Some(env_vars) = &self.env_vars
+            && env_vars.len() == 1
+            && env_vars[0].value.is_none()
+            && !self.prompt
+        {
+            let key = &env_vars[0].key;
+            // Use Config's centralized env loading which handles decryption
+            let full_config = Config::get().await?;
+            let env = full_config.env().await?;
+            match env.get(key) {
+                Some(value) => {
+                    miseprintln!("{value}");
                 }
-                return Ok(());
+                None => bail!("Environment variable {key} not found"),
             }
+            return Ok(());
         }
 
         if let Some(mut env_vars) = self.env_vars.take() {
