@@ -124,12 +124,12 @@ impl Unuse {
                     .keys()
                     .any(|ba| self.installed_tool.iter().any(|ta| &ta.ba == ba))
                 {
-                    return config_file::parse(cf.get_path());
+                    return config_file::parse(cf.get_path()).await;
                 }
             }
             config::local_toml_config_path()
         };
-        config_file::parse_or_init(&path)
+        config_file::parse_or_init(&path).await
     }
 }
 
