@@ -111,13 +111,12 @@ impl Upgrade {
         let config_file_updates = outdated_with_config_files
             .iter()
             .filter(|(o, cf)| {
-                if let Ok(trs) = cf.to_tool_request_set() {
-                    if let Some(versions) = trs.tools.get(o.tool_request.ba()) {
-                        if versions.len() != 1 {
-                            warn!("upgrading multiple versions with --bump is not yet supported");
-                            return false;
-                        }
-                    }
+                if let Ok(trs) = cf.to_tool_request_set()
+                    && let Some(versions) = trs.tools.get(o.tool_request.ba())
+                    && versions.len() != 1
+                {
+                    warn!("upgrading multiple versions with --bump is not yet supported");
+                    return false;
                 }
                 true
             })
