@@ -161,21 +161,20 @@ impl Use {
                 .into_iter()
                 .map(|tv| {
                     let mut request = tv.request.clone();
-                    if pin {
-                        if let ToolRequest::Version {
+                    if pin
+                        && let ToolRequest::Version {
                             version: _version,
                             source,
                             options,
                             backend,
                         } = request
-                        {
-                            request = ToolRequest::Version {
-                                version: tv.version.clone(),
-                                source,
-                                options,
-                                backend,
-                            };
-                        }
+                    {
+                        request = ToolRequest::Version {
+                            version: tv.version.clone(),
+                            source,
+                            options,
+                            backend,
+                        };
                     }
                     request
                 })
@@ -244,12 +243,11 @@ impl Use {
             warn!("{plugin} is defined in {p} which overrides the global config ({global})");
         };
         for targ in &self.tool {
-            if let Some(tv) = ts.versions.get(targ.ba.as_ref()) {
-                if let ToolSource::MiseToml(p) | ToolSource::ToolVersions(p) = &tv.source {
-                    if !file::same_file(p, global) {
-                        warn(targ, p);
-                    }
-                }
+            if let Some(tv) = ts.versions.get(targ.ba.as_ref())
+                && let ToolSource::MiseToml(p) | ToolSource::ToolVersions(p) = &tv.source
+                && !file::same_file(p, global)
+            {
+                warn(targ, p);
             }
         }
     }
