@@ -801,26 +801,24 @@ pub(crate) fn resolve_task_pattern(pattern: &str, parent_task: Option<&Task>) ->
     let should_resolve_relatively = pattern.starts_with(':') && !pattern.starts_with("::")
         || (is_bare_name && parent_task.is_some_and(|p| p.name.starts_with("//")));
 
-    if should_resolve_relatively {
-        if let Some(parent) = parent_task {
-            // Extract the path portion from the parent task name
-            // For monorepo tasks like "//projects/frontend:test:nested", we need to extract "//projects/frontend"
-            // by finding the FIRST colon after the "//" prefix, not the last one
-            if let Some(stripped) = parent.name.strip_prefix("//") {
-                // Find the first colon after "//" prefix
-                if let Some(colon_idx) = stripped.find(':') {
-                    let path = format!("//{}", &stripped[..colon_idx]);
-                    // If pattern is a bare name, add the colon prefix
-                    return if is_bare_name {
-                        format!("{}:{}", path, pattern)
-                    } else {
-                        format!("{}{}", path, pattern)
-                    };
-                }
-            } else if let Some((path, _)) = parent.name.rsplit_once(':') {
-                // For non-monorepo tasks, use the old logic
-                return format!("{}{}", path, pattern);
+    if should_resolve_relatively && let Some(parent) = parent_task {
+        // Extract the path portion from the parent task name
+        // For monorepo tasks like "//projects/frontend:test:nested", we need to extract "//projects/frontend"
+        // by finding the FIRST colon after the "//" prefix, not the last one
+        if let Some(stripped) = parent.name.strip_prefix("//") {
+            // Find the first colon after "//" prefix
+            if let Some(colon_idx) = stripped.find(':') {
+                let path = format!("//{}", &stripped[..colon_idx]);
+                // If pattern is a bare name, add the colon prefix
+                return if is_bare_name {
+                    format!("{}:{}", path, pattern)
+                } else {
+                    format!("{}{}", path, pattern)
+                };
             }
+        } else if let Some((path, _)) = parent.name.rsplit_once(':') {
+            // For non-monorepo tasks, use the old logic
+            return format!("{}{}", path, pattern);
         }
     }
     pattern.to_string()
